==> seedsui-react-5.5.91.tgz: package/lib/BiDoughnut/BiDoughnut.js <==
var _excluded = ["style", "borderWidth", "size", "duration", "rotate", "delay", "captionAttribute", "children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BiDoughnut = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var style = _ref.style,
      _ref$borderWidth = _ref.borderWidth,
      borderWidth = _ref$borderWidth === void 0 ? 3 : _ref$borderWidth,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 50 : _ref$size,
      _ref$duration = _ref.duration,
      duration = _ref$duration === void 0 ? 1000 : _ref$duration,
      _ref$rotate = _ref.rotate,
      rotate = _ref$rotate === void 0 ? 0 : _ref$rotate,
      _ref$delay = _ref.delay,
      delay = _ref$delay === void 0 ? 100 : _ref$delay,
      _ref$captionAttribute = _ref.captionAttribute,
      captionAttribute = _ref$captionAttribute === void 0 ? {} : _ref$captionAttribute,
      children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var leftCircleRef = useRef(null);
  var rightCircleRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });

  function getDuration() {
    var correctRotate = rotate > 360 ? 360 : rotate;
    var duration1 = duration / 360;
    var durationRotate = duration1 * correctRotate;
    var durationLeft = 0;
    var durationRight = durationRotate;

    if (correctRotate > 180) {
      durationRight = duration1 * 180;
      durationLeft = duration1 * (correctRotate - 180);
    }

    return {
      durationRotate: durationRotate,
      delayLeft: durationRight,
      durationLeft: durationLeft,
      durationRight: durationRight
    };
  }

  function getRotate() {
    var rotateLeft = -135; // 左circle旋转角度

    var rotateRight = -135 + rotate; // 右circle旋转角度

    if (rotate > 180) {
      rotateRight = 45;
      rotateLeft = -135 + (rotate - 180);
    }

    return {
      rotateLeft: rotateLeft,
      rotateRight: rotateRight
    };
  } // 只有延迟100毫秒动画才会生效


  function aniRotate() {
    // 时长与延时
    var duration = getDuration();
    var durationLeft = duration.durationLeft;
    var delayLeft = duration.delayLeft;
    var durationRight = duration.durationRight; // 旋转

    var rotate = getRotate();
    var rotateLeft = rotate.rotateLeft;
    var rotateRight = rotate.rotateRight;
    setTimeout(function () {
      if (leftCircleRef.current) {
        leftCircleRef.current.style.WebkitTransitionDuration = "".concat(durationLeft, "ms");
        leftCircleRef.current.style.WebkitTransitionDelay = "".concat(delayLeft, "ms");
      }

      if (rightCircleRef.current) {
        rightCircleRef.current.style.WebkitTransitionDuration = "".concat(durationRight, "ms");
      }

      if (leftCircleRef.current) {
        leftCircleRef.current.style.WebkitTransform = "rotate(".concat(rotateLeft, "deg)");
      }

      if (rightCircleRef.current) {
        rightCircleRef.current.style.WebkitTransform = "rotate(".concat(rotateRight, "deg)");
      }
    }, delay);
  } // 动画旋转


  aniRotate();
  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
    ref: rootRef
  }, others), {}, {
    className: "bi-doughtut".concat(others.className ? ' ' + others.className : ''),
    style: Object.assign({
      width: "".concat(size, "px"),
      height: "".concat(size, "px")
    }, style || {}),
    children: [/*#__PURE__*/_jsx("div", {
      className: "bi-doughtut-wrapper left",
      children: /*#__PURE__*/_jsx("div", {
        ref: leftCircleRef,
        className: "bi-doughtut-circle left",
        style: {
          borderWidth: "".concat(borderWidth, "px"),
          width: "".concat(size - borderWidth * 2, "px"),
          height: "".concat(size - borderWidth * 2, "px")
        }
      })
    }), /*#__PURE__*/_jsx("div", {
      className: "bi-doughtut-wrapper right",
      children: /*#__PURE__*/_jsx("div", {
        ref: rightCircleRef,
        className: "bi-doughtut-circle right",
        style: {
          borderWidth: "".concat(borderWidth, "px"),
          width: "".concat(size - borderWidth * 2, "px"),
          height: "".concat(size - borderWidth * 2, "px")
        }
      })
    }), /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({}, captionAttribute), {}, {
      className: "bi-doughtut-caption".concat(captionAttribute.className ? ' ' + captionAttribute.className : ''),
      children: children
    }))]
  }));
});
export default BiDoughnut;

==> seedsui-react-5.5.92.tgz: package/lib/BiDoughnut/BiDoughnut.js <==
var _excluded = ["style", "borderWidth", "size", "duration", "rotate", "delay", "captionAttribute", "children"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle } from 'react';
var BiDoughnut = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var style = _ref.style,
      _ref$borderWidth = _ref.borderWidth,
      borderWidth = _ref$borderWidth === void 0 ? 3 : _ref$borderWidth,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 50 : _ref$size,
      _ref$duration = _ref.duration,
      duration = _ref$duration === void 0 ? 1000 : _ref$duration,
      _ref$rotate = _ref.rotate,
      rotate = _ref$rotate === void 0 ? 0 : _ref$rotate,
      _ref$delay = _ref.delay,
      delay = _ref$delay === void 0 ? 100 : _ref$delay,
      _ref$captionAttribute = _ref.captionAttribute,
      captionAttribute = _ref$captionAttribute === void 0 ? {} : _ref$captionAttribute,
      children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var leftCircleRef = useRef(null);
  var rightCircleRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });

  function getDuration() {
    var correctRotate = rotate > 360 ? 360 : rotate;
    var duration1 = duration / 360;
    var durationRotate = duration1 * correctRotate;
    var durationLeft = 0;
    var durationRight = durationRotate;

    if (correctRotate > 180) {
      durationRight = duration1 * 180;
      durationLeft = duration1 * (correctRotate - 180);
    }

    return {
      durationRotate: durationRotate,
      delayLeft: durationRight,
      durationLeft: durationLeft,
      durationRight: durationRight
    };
  }

  function getRotate() {
    var rotateLeft = -135; // 左circle旋转角度

    var rotateRight = -135 + rotate; // 右circle旋转角度

    if (rotate > 180) {
      rotateRight = 45;
      rotateLeft = -135 + (rotate - 180);
    }

    return {
      rotateLeft: rotateLeft,
      rotateRight: rotateRight
    };
  } // 只有延迟100毫秒动画才会生效


  function aniRotate() {
    // 时长与延时
    var duration = getDuration();
    var durationLeft = duration.durationLeft;
    var delayLeft = duration.delayLeft;
    var durationRight = duration.durationRight; // 旋转

    var rotate = getRotate();
    var rotateLeft = rotate.rotateLeft;
    var rotateRight = rotate.rotateRight;
    setTimeout(function () {
      if (leftCircleRef.current) {
        leftCircleRef.current.style.WebkitTransitionDuration = "".concat(durationLeft, "ms");
        leftCircleRef.current.style.WebkitTransitionDelay = "".concat(delayLeft, "ms");
      }

      if (rightCircleRef.current) {
        rightCircleRef.current.style.WebkitTransitionDuration = "".concat(durationRight, "ms");
      }

      if (leftCircleRef.current) {
        leftCircleRef.current.style.WebkitTransform = "rotate(".concat(rotateLeft, "deg)");
      }

      if (rightCircleRef.current) {
        rightCircleRef.current.style.WebkitTransform = "rotate(".concat(rotateRight, "deg)");
      }
    }, delay);
  } // 动画旋转


  aniRotate();
  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, others, {
    className: "bi-doughtut".concat(others.className ? ' ' + others.className : ''),
    style: Object.assign({
      width: "".concat(size, "px"),
      height: "".concat(size, "px")
    }, style || {})
  }), /*#__PURE__*/React.createElement("div", {
    className: "bi-doughtut-wrapper left"
  }, /*#__PURE__*/React.createElement("div", {
    ref: leftCircleRef,
    className: "bi-doughtut-circle left",
    style: {
      borderWidth: "".concat(borderWidth, "px"),
      width: "".concat(size - borderWidth * 2, "px"),
      height: "".concat(size - borderWidth * 2, "px")
    }
  })), /*#__PURE__*/React.createElement("div", {
    className: "bi-doughtut-wrapper right"
  }, /*#__PURE__*/React.createElement("div", {
    ref: rightCircleRef,
    className: "bi-doughtut-circle right",
    style: {
      borderWidth: "".concat(borderWidth, "px"),
      width: "".concat(size - borderWidth * 2, "px"),
      height: "".concat(size - borderWidth * 2, "px")
    }
  })), /*#__PURE__*/React.createElement("div", _extends({}, captionAttribute, {
    className: "bi-doughtut-caption".concat(captionAttribute.className ? ' ' + captionAttribute.className : '')
  }), children));
});
export default BiDoughnut;
